package cn.com.infosec.asn1.pkcs;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.DigestInfo;
import java.math.BigInteger;

public class MacData extends ASN1Encodable {
   DigestInfo digInfo;
   byte[] salt;
   BigInteger iterationCount;

   public static MacData getInstance(Object obj) {
      if (obj instanceof MacData) {
         return (MacData)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new MacData((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public MacData(ASN1Sequence seq) {
      this.digInfo = DigestInfo.getInstance(seq.getObjectAt(0));
      this.salt = ((ASN1OctetString)seq.getObjectAt(1)).getOctets();
      if (seq.size() == 3) {
         this.iterationCount = ((DERInteger)seq.getObjectAt(2)).getValue();
      } else {
         this.iterationCount = BigInteger.valueOf(1L);
      }

   }

   public MacData(DigestInfo digInfo, byte[] salt, int iterationCount) {
      this.digInfo = digInfo;
      this.salt = salt;
      this.iterationCount = BigInteger.valueOf((long)iterationCount);
   }

   public DigestInfo getMac() {
      return this.digInfo;
   }

   public byte[] getSalt() {
      return this.salt;
   }

   public BigInteger getIterationCount() {
      return this.iterationCount;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10000.add(this.digInfo);
      var10000.add(new DEROctetString(this.salt));
      var10000.add(new DERInteger(this.iterationCount));
      return new DERSequence(var1);
   }
}
